==> openshift-model-monitoring-6.7.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusStatusBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrometheusStatusBuilder extends PrometheusStatusFluentImpl<PrometheusStatusBuilder> implements VisitableBuilder<PrometheusStatus,PrometheusStatusBuilder>{
  public PrometheusStatusBuilder() {
    this(false);
  }
  public PrometheusStatusBuilder(Boolean validationEnabled) {
    this(new PrometheusStatus(), validationEnabled);
  }
  public PrometheusStatusBuilder(PrometheusStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusStatusBuilder(PrometheusStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PrometheusStatus(), validationEnabled);
  }
  public PrometheusStatusBuilder(PrometheusStatusFluent<?> fluent,PrometheusStatus instance) {
    this(fluent, instance, false);
  }
  public PrometheusStatusBuilder(PrometheusStatusFluent<?> fluent,PrometheusStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAvailableReplicas(instance.getAvailableReplicas());
      fluent.withPaused(instance.getPaused());
      fluent.withReplicas(instance.getReplicas());
      fluent.withUnavailableReplicas(instance.getUnavailableReplicas());
      fluent.withUpdatedReplicas(instance.getUpdatedReplicas());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PrometheusStatusBuilder(PrometheusStatus instance) {
    this(instance,false);
  }
  public PrometheusStatusBuilder(PrometheusStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAvailableReplicas(instance.getAvailableReplicas());
      this.withPaused(instance.getPaused());
      this.withReplicas(instance.getReplicas());
      this.withUnavailableReplicas(instance.getUnavailableReplicas());
      this.withUpdatedReplicas(instance.getUpdatedReplicas());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PrometheusStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PrometheusStatus build() {
    PrometheusStatus buildable = new PrometheusStatus(fluent.getAvailableReplicas(),fluent.getPaused(),fluent.getReplicas(),fluent.getUnavailableReplicas(),fluent.getUpdatedReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusStatusBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrometheusStatusBuilder extends PrometheusStatusFluent<PrometheusStatusBuilder> implements VisitableBuilder<PrometheusStatus,PrometheusStatusBuilder>{
  public PrometheusStatusBuilder() {
    this(false);
  }
  public PrometheusStatusBuilder(Boolean validationEnabled) {
    this(new PrometheusStatus(), validationEnabled);
  }
  public PrometheusStatusBuilder(PrometheusStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusStatusBuilder(PrometheusStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PrometheusStatus(), validationEnabled);
  }
  public PrometheusStatusBuilder(PrometheusStatusFluent<?> fluent,PrometheusStatus instance) {
    this(fluent, instance, false);
  }
  public PrometheusStatusBuilder(PrometheusStatusFluent<?> fluent,PrometheusStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PrometheusStatus());

    if (instance != null) {
      fluent.withAvailableReplicas(instance.getAvailableReplicas());
      fluent.withConditions(instance.getConditions());
      fluent.withPaused(instance.getPaused());
      fluent.withReplicas(instance.getReplicas());
      fluent.withShardStatuses(instance.getShardStatuses());
      fluent.withUnavailableReplicas(instance.getUnavailableReplicas());
      fluent.withUpdatedReplicas(instance.getUpdatedReplicas());
      fluent.withAvailableReplicas(instance.getAvailableReplicas());
      fluent.withConditions(instance.getConditions());
      fluent.withPaused(instance.getPaused());
      fluent.withReplicas(instance.getReplicas());
      fluent.withShardStatuses(instance.getShardStatuses());
      fluent.withUnavailableReplicas(instance.getUnavailableReplicas());
      fluent.withUpdatedReplicas(instance.getUpdatedReplicas());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PrometheusStatusBuilder(PrometheusStatus instance) {
    this(instance,false);
  }
  public PrometheusStatusBuilder(PrometheusStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PrometheusStatus());

    if (instance != null) {
      this.withAvailableReplicas(instance.getAvailableReplicas());
      this.withConditions(instance.getConditions());
      this.withPaused(instance.getPaused());
      this.withReplicas(instance.getReplicas());
      this.withShardStatuses(instance.getShardStatuses());
      this.withUnavailableReplicas(instance.getUnavailableReplicas());
      this.withUpdatedReplicas(instance.getUpdatedReplicas());
      this.withAvailableReplicas(instance.getAvailableReplicas());
      this.withConditions(instance.getConditions());
      this.withPaused(instance.getPaused());
      this.withReplicas(instance.getReplicas());
      this.withShardStatuses(instance.getShardStatuses());
      this.withUnavailableReplicas(instance.getUnavailableReplicas());
      this.withUpdatedReplicas(instance.getUpdatedReplicas());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PrometheusStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PrometheusStatus build() {
    PrometheusStatus buildable = new PrometheusStatus(fluent.getAvailableReplicas(),fluent.buildConditions(),fluent.getPaused(),fluent.getReplicas(),fluent.buildShardStatuses(),fluent.getUnavailableReplicas(),fluent.getUpdatedReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
